==> haskell-data-clist-0.1.2.2-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-clist
version: 0.1.2.2
id: data-clist-0.1.2.2-5Mu4gig0Gc7K1xGBgRoMnG
key: data-clist-0.1.2.2-5Mu4gig0Gc7K1xGBgRoMnG
license: BSD-3-Clause
maintainer: Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>
author: John Van Enk <vanenkj@gmail.com>
stability: experimental
homepage: https://github.com/sw17ch/data-clist
synopsis: Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.
category: Data Structures
abi: 7067d8bdaecb040ab824d1c9214e900a
exposed: True
exposed-modules:
    Data.CircularList
import-dirs: /usr/lib/ghc-8.6.5/site-local/data-clist-0.1.2.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/data-clist-0.1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/data-clist-0.1.2.2
hs-libraries: HSdata-clist-0.1.2.2-5Mu4gig0Gc7K1xGBgRoMnG
depends:
    QuickCheck-2.13.1-BED53w0KTtOAjBW8qj2Yxi base-4.12.0.0
    deepseq-1.4.4.0
haddock-interfaces: /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html: /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-clist-0.1.2.2-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-clist
version: 0.1.2.2
id: data-clist-0.1.2.2-IoLhYnvwkJk3U8mo1aTgQA
key: data-clist-0.1.2.2-IoLhYnvwkJk3U8mo1aTgQA
license: BSD-3-Clause
maintainer: Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>
author: John Van Enk <vanenkj@gmail.com>
stability: experimental
homepage: https://github.com/sw17ch/data-clist
synopsis: Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.
category: Data Structures
abi: e2c2eec55e1f52b50d9c5cbf3a311e0e
exposed: True
exposed-modules:
    Data.CircularList
import-dirs: /usr/lib/ghc-8.6.5/site-local/data-clist-0.1.2.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/data-clist-0.1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/data-clist-0.1.2.2
hs-libraries: HSdata-clist-0.1.2.2-IoLhYnvwkJk3U8mo1aTgQA
depends:
    QuickCheck-2.13.1-7krqagqcRmA9RWDtUhyOg8 base-4.12.0.0
    deepseq-1.4.4.0
haddock-interfaces: /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html: /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
